requirements = """
aiocontextvars==0.2.2
alembic==1.3.2
astroid==2.3.3
asyncpg==0.20.1
attrs==19.3.0
bson==0.5.8
certifi==2019.11.28
chardet==3.0.4
Click==7.0
databases==0.2.6
dnspython==1.16.0
docutils==0.15.2
email-validator==1.0.5
fastapi==0.45.0
gino==0.8.5
h11==0.9.0
h2==3.2.0
hpack==3.0.0
hstspreload==2020.2.5
httptools==0.0.13
httpx==0.11.1
hyperframe==5.2.0
idna==2.8
isort==4.3.21
jmespath==0.9.5
lazy-object-proxy==1.4.3
Mako==1.1.0
MarkupSafe==1.1.1
mccabe==0.6.1
outcome==1.0.1
pipenv==2018.11.26
prometheus-client==0.7.1
{}
pydantic==1.3
pylint==2.4.4
python-dateutil==2.8.1
python-editor==1.0.4
Represent==1.6.0
requests==2.22.0
rfc3986==1.3.2
s3transfer==0.3.3
sentry-sdk==0.14.0
six==1.13.0
sniffio==1.1.0
SQLAlchemy==1.3.13
SQLAlchemy-Utils==0.36.1
starlette==0.12.9
starlette-prometheus==0.5.0
typed-ast==1.4.0
urllib3==1.25.7
uvicorn==0.11.1
uvloop==0.14.0
virtualenv==16.7.9
virtualenv-clone==0.5.3
websockets==8.1
wrapt==1.11.2

"""
